You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by tn...@apache.org on 2015/06/22 15:00:30 UTC

svn commit: r1686855 [3/5] - in /commons/proper/collections/trunk/src: changes/ main/java/org/apache/commons/collections4/ main/java/org/apache/commons/collections4/bag/ main/java/org/apache/commons/collections4/bidimap/ main/java/org/apache/commons/co...

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InvokerTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InvokerTransformer.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InvokerTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/InvokerTransformer.java Mon Jun 22 13:00:27 2015
@@ -48,11 +48,12 @@ public class InvokerTransformer<I, O> im
      * @param <O>  the output type
      * @param methodName  the method name to call
      * @return an invoker transformer
+     * @throws NullPointerException if methodName is null
      * @since 3.1
      */
     public static <I, O> Transformer<I, O> invokerTransformer(final String methodName) {
         if (methodName == null) {
-            throw new IllegalArgumentException("The method to invoke must not be null");
+            throw new NullPointerException("The method to invoke must not be null");
         }
         return new InvokerTransformer<I, O>(methodName);
     }
@@ -66,11 +67,13 @@ public class InvokerTransformer<I, O> im
      * @param paramTypes  the parameter types of the method
      * @param args  the arguments to pass to the method
      * @return an invoker transformer
+     * @throws NullPointerException if methodName is null
+     * @throws IllegalArgumentException if paramTypes does not match args
      */
     public static <I, O> Transformer<I, O> invokerTransformer(final String methodName, final Class<?>[] paramTypes,
                                                               final Object[] args) {
         if (methodName == null) {
-            throw new IllegalArgumentException("The method to invoke must not be null");
+            throw new NullPointerException("The method to invoke must not be null");
         }
         if (((paramTypes == null) && (args != null))
             || ((paramTypes != null) && (args == null))

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NonePredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NonePredicate.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NonePredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NonePredicate.java Mon Jun 22 13:00:27 2015
@@ -44,8 +44,8 @@ public final class NonePredicate<T> exte
      * @param <T> the type that the predicate queries
      * @param predicates  the predicates to check, cloned, not null
      * @return the <code>any</code> predicate
-     * @throws IllegalArgumentException if the predicates array is null
-     * @throws IllegalArgumentException if any predicate in the array is null
+     * @throws NullPointerException if the predicates array is null
+     * @throws NullPointerException if any predicate in the array is null
      */
     public static <T> Predicate<T> nonePredicate(final Predicate<? super T>... predicates) {
         FunctorUtils.validate(predicates);
@@ -63,8 +63,8 @@ public final class NonePredicate<T> exte
      * @param <T> the type that the predicate queries
      * @param predicates  the predicates to check, cloned, not null
      * @return the <code>one</code> predicate
-     * @throws IllegalArgumentException if the predicates array is null
-     * @throws IllegalArgumentException if any predicate in the array is null
+     * @throws NullPointerException if the predicates array is null
+     * @throws NullPointerException if any predicate in the array is null
      */
     public static <T> Predicate<T> nonePredicate(final Collection<? extends Predicate<? super T>> predicates) {
         final Predicate<? super T>[] preds = FunctorUtils.validate(predicates);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NotPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NotPredicate.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OnePredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OnePredicate.java Mon Jun 22 13:00:27 2015
@@ -45,8 +45,8 @@ public final class OnePredicate<T> exten
      * @param <T> the type that the predicate queries
      * @param predicates  the predicates to check, cloned, not null
      * @return the <code>any</code> predicate
-     * @throws IllegalArgumentException if the predicates array is null
-     * @throws IllegalArgumentException if any predicate in the array is null
+     * @throws NullPointerException if the predicates array is null
+     * @throws NullPointerException if any predicate in the array is null
      */
     @SuppressWarnings("unchecked")
     public static <T> Predicate<T> onePredicate(final Predicate<? super T>... predicates) {
@@ -66,8 +66,8 @@ public final class OnePredicate<T> exten
      * @param <T> the type that the predicate queries
      * @param predicates  the predicates to check, cloned, not null
      * @return the <code>one</code> predicate
-     * @throws IllegalArgumentException if the predicates array is null
-     * @throws IllegalArgumentException if any predicate in the array is null
+     * @throws NullPointerException if the predicates array is null
+     * @throws NullPointerException if any predicate in the array is null
      */
     public static <T> Predicate<T> onePredicate(final Collection<? extends Predicate<? super T>> predicates) {
         final Predicate<? super T>[] preds = FunctorUtils.validate(predicates);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OrPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OrPredicate.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractIteratorDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractIteratorDecorator.java Mon Jun 22 13:00:27 2015
@@ -33,7 +33,7 @@ public abstract class AbstractIteratorDe
      * Constructor that decorates the specified iterator.
      *
      * @param iterator  the iterator to decorate, must not be null
-     * @throws IllegalArgumentException if the collection is null
+     * @throws NullPointerException if the iterator is null
      */
     protected AbstractIteratorDecorator(final Iterator<E> iterator) {
         super(iterator);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractListIteratorDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractListIteratorDecorator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractListIteratorDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractListIteratorDecorator.java Mon Jun 22 13:00:27 2015
@@ -36,12 +36,12 @@ public class AbstractListIteratorDecorat
      * Constructor that decorates the specified iterator.
      *
      * @param iterator  the iterator to decorate, must not be null
-     * @throws IllegalArgumentException if the collection is null
+     * @throws NullPointerException if the iterator is null
      */
     public AbstractListIteratorDecorator(final ListIterator<E> iterator) {
         super();
         if (iterator == null) {
-            throw new IllegalArgumentException("ListIterator must not be null");
+            throw new NullPointerException("ListIterator must not be null");
         }
         this.iterator = iterator;
     }

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractMapIteratorDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractMapIteratorDecorator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractMapIteratorDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractMapIteratorDecorator.java Mon Jun 22 13:00:27 2015
@@ -36,12 +36,12 @@ public class AbstractMapIteratorDecorato
      * Constructor that decorates the specified iterator.
      *
      * @param iterator  the iterator to decorate, must not be null
-     * @throws IllegalArgumentException if the collection is null
+     * @throws NullPointerException if the iterator is null
      */
     public AbstractMapIteratorDecorator(final MapIterator<K, V> iterator) {
         super();
         if (iterator == null) {
-            throw new IllegalArgumentException("MapIterator must not be null");
+            throw new NullPointerException("MapIterator must not be null");
         }
         this.iterator = iterator;
     }

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractOrderedMapIteratorDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractOrderedMapIteratorDecorator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractOrderedMapIteratorDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractOrderedMapIteratorDecorator.java Mon Jun 22 13:00:27 2015
@@ -36,12 +36,12 @@ public class AbstractOrderedMapIteratorD
      * Constructor that decorates the specified iterator.
      *
      * @param iterator  the iterator to decorate, must not be null
-     * @throws IllegalArgumentException if the collection is null
+     * @throws NullPointerException if the iterator is null
      */
     public AbstractOrderedMapIteratorDecorator(final OrderedMapIterator<K, V> iterator) {
         super();
         if (iterator == null) {
-            throw new IllegalArgumentException("OrderedMapIterator must not be null");
+            throw new NullPointerException("OrderedMapIterator must not be null");
         }
         this.iterator = iterator;
     }

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractUntypedIteratorDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractUntypedIteratorDecorator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractUntypedIteratorDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractUntypedIteratorDecorator.java Mon Jun 22 13:00:27 2015
@@ -36,11 +36,12 @@ public abstract class AbstractUntypedIte
      * Create a new AbstractUntypedIteratorDecorator.
      *
      * @param iterator  the iterator to decorate
+     * @throws NullPointerException if the iterator is null
      */
     protected AbstractUntypedIteratorDecorator(final Iterator<I> iterator) {
         super();
         if (iterator == null) {
-            throw new IllegalArgumentException("Iterator must not be null");
+            throw new NullPointerException("Iterator must not be null");
         }
         this.iterator = iterator;
     }

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/BoundedIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/BoundedIterator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/ReverseListIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/ReverseListIterator.java Mon Jun 22 13:00:27 2015
@@ -53,6 +53,9 @@ public class ReverseListIterator<E> impl
      */
     public ReverseListIterator(final List<E> list) {
         super();
+        if (list == null) {
+            throw new NullPointerException("List must not be null.");
+        }
         this.list = list;
         iterator = list.listIterator(list.size());
     }

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableIterator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/AbstractListDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/AbstractListDecorator.java Mon Jun 22 13:00:27 2015
@@ -49,7 +49,7 @@ public abstract class AbstractListDecora
      * Constructor that wraps (not copies).
      *
      * @param list  the list to decorate, must not be null
-     * @throws IllegalArgumentException if list is null
+     * @throws NullPointerException if list is null
      */
     protected AbstractListDecorator(final List<E> list) {
         super(list);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/AbstractSerializableListDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/AbstractSerializableListDecorator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/AbstractSerializableListDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/AbstractSerializableListDecorator.java Mon Jun 22 13:00:27 2015
@@ -38,7 +38,7 @@ public abstract class AbstractSerializab
      * Constructor that wraps (not copies).
      *
      * @param list  the list to decorate, must not be null
-     * @throws IllegalArgumentException if list is null
+     * @throws NullPointerException if list is null
      */
     protected AbstractSerializableListDecorator(final List<E> list) {
         super(list);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/FixedSizeList.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/FixedSizeList.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/FixedSizeList.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/FixedSizeList.java Mon Jun 22 13:00:27 2015
@@ -49,7 +49,7 @@ public class FixedSizeList<E>
      * @param <E> the type of the elements in the list
      * @param list  the list to decorate, must not be null
      * @return a new fixed size list
-     * @throws IllegalArgumentException if list is null
+     * @throws NullPointerException if list is null
      * @since 4.0
      */
     public static <E> FixedSizeList<E> fixedSizeList(final List<E> list) {
@@ -61,7 +61,7 @@ public class FixedSizeList<E>
      * Constructor that wraps (not copies).
      *
      * @param list  the list to decorate, must not be null
-     * @throws IllegalArgumentException if list is null
+     * @throws NullPointerException if list is null
      */
     protected FixedSizeList(final List<E> list) {
         super(list);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/GrowthList.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/GrowthList.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/GrowthList.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/GrowthList.java Mon Jun 22 13:00:27 2015
@@ -63,7 +63,7 @@ public class GrowthList<E> extends Abstr
      * @param <E> the type of the elements in the list
      * @param list  the list to decorate, must not be null
      * @return a new growth list
-     * @throws IllegalArgumentException if list is null
+     * @throws NullPointerException if list is null
      * @since 4.0
      */
     public static <E> GrowthList<E> growthList(final List<E> list) {
@@ -92,7 +92,7 @@ public class GrowthList<E> extends Abstr
      * Constructor that wraps (not copies).
      *
      * @param list  the list to decorate, must not be null
-     * @throws IllegalArgumentException if list is null
+     * @throws NullPointerException if list is null
      */
     protected GrowthList(final List<E> list) {
         super(list);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/LazyList.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/LazyList.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/LazyList.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/LazyList.java Mon Jun 22 13:00:27 2015
@@ -72,7 +72,7 @@ public class LazyList<E> extends Abstrac
      * @param list  the list to decorate, must not be null
      * @param factory  the factory to use for creation, must not be null
      * @return a new lazy list
-     * @throws IllegalArgumentException if list or factory is null
+     * @throws NullPointerException if list or factory is null
      * @since 4.0
      */
     public static <E> LazyList<E> lazyList(final List<E> list, final Factory<? extends E> factory) {
@@ -85,7 +85,7 @@ public class LazyList<E> extends Abstrac
      *
      * @param list  the list to decorate, must not be null
      * @param factory  the factory to use for creation, must not be null
-     * @throws IllegalArgumentException if list or factory is null
+     * @throws NullPointerException if list or factory is null
      */
     protected LazyList(final List<E> list, final Factory<? extends E> factory) {
         super(list);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/PredicatedList.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/PredicatedList.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/PredicatedList.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/PredicatedList.java Mon Jun 22 13:00:27 2015
@@ -60,7 +60,7 @@ public class PredicatedList<E> extends P
      * @param list  the list to decorate, must not be null
      * @param predicate  the predicate to use for validation, must not be null
      * @return a new predicated list
-     * @throws IllegalArgumentException if list or predicate is null
+     * @throws NullPointerException if list or predicate is null
      * @throws IllegalArgumentException if the list contains invalid elements
      * @since 4.0
      */
@@ -77,7 +77,7 @@ public class PredicatedList<E> extends P
      *
      * @param list  the list to decorate, must not be null
      * @param predicate  the predicate to use for validation, must not be null
-     * @throws IllegalArgumentException if list or predicate is null
+     * @throws NullPointerException if list or predicate is null
      * @throws IllegalArgumentException if the list contains invalid elements
      */
     protected PredicatedList(final List<E> list, final Predicate<? super E> predicate) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/SetUniqueList.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/SetUniqueList.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/TransformedList.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/TransformedList.java Mon Jun 22 13:00:27 2015
@@ -53,7 +53,7 @@ public class TransformedList<E> extends
      * @param list  the list to decorate, must not be null
      * @param transformer  the transformer to use for conversion, must not be null
      * @return a new transformed list
-     * @throws IllegalArgumentException if list or transformer is null
+     * @throws NullPointerException if list or transformer is null
      * @since 4.0
      */
     public static <E> TransformedList<E> transformingList(final List<E> list,
@@ -73,13 +73,13 @@ public class TransformedList<E> extends
      * @param list  the list to decorate, must not be null
      * @param transformer  the transformer to use for conversion, must not be null
      * @return a new transformed List
-     * @throws IllegalArgumentException if list or transformer is null
+     * @throws NullPointerException if list or transformer is null
      * @since 4.0
      */
     public static <E> TransformedList<E> transformedList(final List<E> list,
                                                          final Transformer<? super E, ? extends E> transformer) {
         final TransformedList<E> decorated = new TransformedList<E>(list, transformer);
-        if (transformer != null && list != null && list.size() > 0) {
+        if (list.size() > 0) {
             @SuppressWarnings("unchecked") // list is of type E
             final E[] values = (E[]) list.toArray(); // NOPMD - false positive for generics
             list.clear();
@@ -99,7 +99,7 @@ public class TransformedList<E> extends
      *
      * @param list  the list to decorate, must not be null
      * @param transformer  the transformer to use for conversion, must not be null
-     * @throws IllegalArgumentException if list or transformer is null
+     * @throws NullPointerException if list or transformer is null
      */
     protected TransformedList(final List<E> list, final Transformer<? super E, ? extends E> transformer) {
         super(list, transformer);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/UnmodifiableList.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/UnmodifiableList.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/UnmodifiableList.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/UnmodifiableList.java Mon Jun 22 13:00:27 2015
@@ -48,7 +48,7 @@ public final class UnmodifiableList<E>
      * @param <E> the type of the elements in the list
      * @param list  the list to decorate, must not be null
      * @return a new unmodifiable list
-     * @throws IllegalArgumentException if list is null
+     * @throws NullPointerException if list is null
      * @since 4.0
      */
     public static <E> List<E> unmodifiableList(final List<? extends E> list) {
@@ -65,7 +65,7 @@ public final class UnmodifiableList<E>
      * Constructor that wraps (not copies).
      *
      * @param list  the list to decorate, must not be null
-     * @throws IllegalArgumentException if list is null
+     * @throws NullPointerException if list is null
      */
     @SuppressWarnings("unchecked") // safe to upcast
     public UnmodifiableList(final List<? extends E> list) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractInputCheckedMapDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractInputCheckedMapDecorator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractInputCheckedMapDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractInputCheckedMapDecorator.java Mon Jun 22 13:00:27 2015
@@ -21,9 +21,9 @@ import java.util.Iterator;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.commons.collections4.set.AbstractSetDecorator;
 import org.apache.commons.collections4.iterators.AbstractIteratorDecorator;
 import org.apache.commons.collections4.keyvalue.AbstractMapEntryDecorator;
+import org.apache.commons.collections4.set.AbstractSetDecorator;
 
 /**
  * An abstract base class that simplifies the task of creating map decorators.
@@ -56,7 +56,7 @@ abstract class AbstractInputCheckedMapDe
      * Constructor that wraps (not copies).
      *
      * @param map  the map to decorate, must not be null
-     * @throws IllegalArgumentException if map is null
+     * @throws NullPointerException if map is null
      */
     protected AbstractInputCheckedMapDecorator(final Map<K, V> map) {
         super(map);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractMapDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractMapDecorator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractMapDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractMapDecorator.java Mon Jun 22 13:00:27 2015
@@ -55,11 +55,11 @@ public abstract class AbstractMapDecorat
      * Constructor that wraps (not copies).
      *
      * @param map  the map to decorate, must not be null
-     * @throws IllegalArgumentException if the collection is null
+     * @throws NullPointerException if the map is null
      */
     protected AbstractMapDecorator(final Map<K, V> map) {
         if (map == null) {
-            throw new IllegalArgumentException("Map must not be null");
+            throw new NullPointerException("Map must not be null.");
         }
         this.map = map;
     }

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractOrderedMapDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractOrderedMapDecorator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractOrderedMapDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractOrderedMapDecorator.java Mon Jun 22 13:00:27 2015
@@ -49,7 +49,7 @@ public abstract class AbstractOrderedMap
      * Constructor that wraps (not copies).
      *
      * @param map  the map to decorate, must not be null
-     * @throws IllegalArgumentException if the collection is null
+     * @throws NullPointerException if the map is null
      */
     public AbstractOrderedMapDecorator(final OrderedMap<K, V> map) {
         super(map);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractSortedMapDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractSortedMapDecorator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractSortedMapDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/AbstractSortedMapDecorator.java Mon Jun 22 13:00:27 2015
@@ -59,7 +59,7 @@ public abstract class AbstractSortedMapD
      * Constructor that wraps (not copies).
      *
      * @param map  the map to decorate, must not be null
-     * @throws IllegalArgumentException if the collection is null
+     * @throws NullPointerException if the map is null
      */
     public AbstractSortedMapDecorator(final SortedMap<K, V> map) {
         super(map);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/DefaultedMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/DefaultedMap.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/FixedSizeMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/FixedSizeMap.java Mon Jun 22 13:00:27 2015
@@ -24,9 +24,9 @@ import java.util.Collection;
 import java.util.Map;
 import java.util.Set;
 
-import org.apache.commons.collections4.set.UnmodifiableSet;
 import org.apache.commons.collections4.BoundedMap;
 import org.apache.commons.collections4.collection.UnmodifiableCollection;
+import org.apache.commons.collections4.set.UnmodifiableSet;
 
 /**
  * Decorates another <code>Map</code> to fix the size, preventing add/remove.
@@ -66,7 +66,7 @@ public class FixedSizeMap<K, V>
      * @param <V>  the value type
      * @param map  the map to decorate, must not be null
      * @return a new fixed size map
-     * @throws IllegalArgumentException if map is null
+     * @throws NullPointerException if map is null
      * @since 4.0
      */
     public static <K, V> FixedSizeMap<K, V> fixedSizeMap(final Map<K, V> map) {
@@ -78,7 +78,7 @@ public class FixedSizeMap<K, V>
      * Constructor that wraps (not copies).
      *
      * @param map  the map to decorate, must not be null
-     * @throws IllegalArgumentException if map is null
+     * @throws NullPointerException if map is null
      */
     protected FixedSizeMap(final Map<K, V> map) {
         super(map);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/FixedSizeSortedMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/FixedSizeSortedMap.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/FixedSizeSortedMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/FixedSizeSortedMap.java Mon Jun 22 13:00:27 2015
@@ -25,10 +25,10 @@ import java.util.Map;
 import java.util.Set;
 import java.util.SortedMap;
 
-import org.apache.commons.collections4.set.UnmodifiableSet;
 import org.apache.commons.collections4.BoundedMap;
 import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.collections4.collection.UnmodifiableCollection;
+import org.apache.commons.collections4.set.UnmodifiableSet;
 
 /**
  * Decorates another <code>SortedMap</code> to fix the size blocking add/remove.
@@ -68,7 +68,7 @@ public class FixedSizeSortedMap<K, V>
      * @param <V>  the value type
      * @param map  the map to decorate, must not be null
      * @return a new fixed size sorted map
-     * @throws IllegalArgumentException if map is null
+     * @throws NullPointerException if map is null
      * @since 4.0
      */
     public static <K, V> FixedSizeSortedMap<K, V> fixedSizeSortedMap(final SortedMap<K, V> map) {
@@ -80,7 +80,7 @@ public class FixedSizeSortedMap<K, V>
      * Constructor that wraps (not copies).
      *
      * @param map  the map to decorate, must not be null
-     * @throws IllegalArgumentException if map is null
+     * @throws NullPointerException if map is null
      */
     protected FixedSizeSortedMap(final SortedMap<K, V> map) {
         super(map);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/LazyMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/LazyMap.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/LazySortedMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/LazySortedMap.java Mon Jun 22 13:00:27 2015
@@ -69,7 +69,7 @@ public class LazySortedMap<K,V> extends
      * @param map  the map to decorate, must not be null
      * @param factory  the factory to use, must not be null
      * @return a new lazy sorted map
-     * @throws IllegalArgumentException if map or factory is null
+     * @throws NullPointerException if map or factory is null
      * @since 4.0
      */
     public static <K, V> LazySortedMap<K, V> lazySortedMap(final SortedMap<K, V> map,
@@ -85,7 +85,7 @@ public class LazySortedMap<K,V> extends
      * @param map  the map to decorate, must not be null
      * @param factory  the factory to use, must not be null
      * @return a new lazy sorted map
-     * @throws IllegalArgumentException if map or factory is null
+     * @throws NullPointerException if map or factory is null
      * @since 4.0
      */
     public static <K, V> LazySortedMap<K, V> lazySortedMap(final SortedMap<K, V> map,
@@ -99,7 +99,7 @@ public class LazySortedMap<K,V> extends
      *
      * @param map  the map to decorate, must not be null
      * @param factory  the factory to use, must not be null
-     * @throws IllegalArgumentException if map or factory is null
+     * @throws NullPointerException if map or factory is null
      */
     protected LazySortedMap(final SortedMap<K,V> map, final Factory<? extends V> factory) {
         super(map, factory);
@@ -110,7 +110,7 @@ public class LazySortedMap<K,V> extends
      *
      * @param map  the map to decorate, must not be null
      * @param factory  the factory to use, must not be null
-     * @throws IllegalArgumentException if map or factory is null
+     * @throws NullPointerException if map or factory is null
      */
     protected LazySortedMap(final SortedMap<K,V> map, final Transformer<? super K, ? extends V> factory) {
         super(map, factory);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/ListOrderedMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/ListOrderedMap.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/ListOrderedMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/ListOrderedMap.java Mon Jun 22 13:00:27 2015
@@ -94,7 +94,7 @@ public class ListOrderedMap<K, V>
      * @param <V>  the value type
      * @param map  the map to decorate, must not be null
      * @return a new list ordered map
-     * @throws IllegalArgumentException if map is null
+     * @throws NullPointerException if map is null
      * @since 4.0
      */
     public static <K, V> ListOrderedMap<K, V> listOrderedMap(final Map<K, V> map) {
@@ -116,7 +116,7 @@ public class ListOrderedMap<K, V>
      * Constructor that wraps (not copies).
      *
      * @param map  the map to decorate, must not be null
-     * @throws IllegalArgumentException if map is null
+     * @throws NullPointerException if map is null
      */
     protected ListOrderedMap(final Map<K, V> map) {
         super(map);

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/MultiKeyMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/MultiKeyMap.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/PredicatedMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/PredicatedMap.java Mon Jun 22 13:00:27 2015
@@ -72,7 +72,7 @@ public class PredicatedMap<K, V>
      * @param keyPredicate  the predicate to validate the keys, null means no check
      * @param valuePredicate  the predicate to validate to values, null means no check
      * @return a new predicated map
-     * @throws IllegalArgumentException if the map is null
+     * @throws NullPointerException if the map is null
      * @since 4.0
      */
     public static <K, V> PredicatedMap<K, V> predicatedMap(final Map<K, V> map,
@@ -88,7 +88,7 @@ public class PredicatedMap<K, V>
      * @param map  the map to decorate, must not be null
      * @param keyPredicate  the predicate to validate the keys, null means no check
      * @param valuePredicate  the predicate to validate to values, null means no check
-     * @throws IllegalArgumentException if the map is null
+     * @throws NullPointerException if the map is null
      */
     protected PredicatedMap(final Map<K, V> map, final Predicate<? super K> keyPredicate,
                             final Predicate<? super V> valuePredicate) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/PredicatedSortedMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/PredicatedSortedMap.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/PredicatedSortedMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/PredicatedSortedMap.java Mon Jun 22 13:00:27 2015
@@ -65,7 +65,7 @@ public class PredicatedSortedMap<K, V> e
      * @param keyPredicate  the predicate to validate the keys, null means no check
      * @param valuePredicate  the predicate to validate to values, null means no check
      * @return a new predicated sorted map
-     * @throws IllegalArgumentException if the map is null
+     * @throws NullPointerException if the map is null
      * @since 4.0
      */
     public static <K, V> PredicatedSortedMap<K, V> predicatedSortedMap(final SortedMap<K, V> map,
@@ -80,7 +80,7 @@ public class PredicatedSortedMap<K, V> e
      * @param map  the map to decorate, must not be null
      * @param keyPredicate  the predicate to validate the keys, null means no check
      * @param valuePredicate  the predicate to validate to values, null means no check
-     * @throws IllegalArgumentException if the map is null
+     * @throws NullPointerException if the map is null
      */
     protected PredicatedSortedMap(final SortedMap<K, V> map, final Predicate<? super K> keyPredicate,
             final Predicate<? super V> valuePredicate) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/SingletonMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/SingletonMap.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/SingletonMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/SingletonMap.java Mon Jun 22 13:00:27 2015
@@ -43,7 +43,7 @@ import org.apache.commons.collections4.k
  * <p>
  * If trying to remove or clear the map, an UnsupportedOperationException is thrown.
  * If trying to put a new mapping into the map, an  IllegalArgumentException is thrown.
- * The put method will only suceed if the key specified is the same as the
+ * The put method will only succeed if the key specified is the same as the
  * singleton key.
  * <p>
  * The key and value can be obtained by:
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NotPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NotPredicate.java Mon Jun 22 13:00:27 2015
@@ -40,11 +40,11 @@ public final class NotPredicate<T> imple
      * @param <T> the type that the predicate queries
      * @param predicate  the predicate to decorate, not null
      * @return the predicate
      * @throws IllegalArgumentException if the predicate is null
      */
     public static <T> Predicate<T> notPredicate(final Predicate<? super T> predicate) {
         if (predicate == null) {
-            throw new IllegalArgumentException("Predicate must not be null");
+            throw new NullPointerException("Predicate must not be null");
         }
         return new NotPredicate<T>(predicate);
     }
@@ -40,11 +40,11 @@ public final class NotPredicate<T> imple
      * @param predicate  the predicate to decorate, not null
      * @return the predicate
-     * @throws IllegalArgumentException if the predicate is null
+     * @throws NullPointerException if the predicate is null
      */
     public static <T> Predicate<T> notPredicate(final Predicate<? super T> predicate) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsExceptionPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsExceptionPredicate.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsExceptionPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsExceptionPredicate.java Mon Jun 22 13:00:27 2015
@@ -41,11 +41,11 @@ public final class NullIsExceptionPredic
      * @param <T> the type that the predicate queries
      * @param predicate  the predicate to decorate, not null
      * @return the predicate
      * @throws IllegalArgumentException if the predicate is null
      */
     public static <T> Predicate<T> nullIsExceptionPredicate(final Predicate<? super T> predicate) {
         if (predicate == null) {
-            throw new IllegalArgumentException("Predicate must not be null");
+            throw new NullPointerException("Predicate must not be null");
         }
         return new NullIsExceptionPredicate<T>(predicate);
     }
@@ -41,11 +41,11 @@ public final class NullIsExceptionPredic
      * @param predicate  the predicate to decorate, not null
      * @return the predicate
-     * @throws IllegalArgumentException if the predicate is null
+     * @throws NullPointerException if the predicate is null
      */
     public static <T> Predicate<T> nullIsExceptionPredicate(final Predicate<? super T> predicate) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsFalsePredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsFalsePredicate.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsFalsePredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsFalsePredicate.java Mon Jun 22 13:00:27 2015
@@ -40,11 +40,11 @@ public final class NullIsFalsePredicate<
      * @param <T> the type that the predicate queries
      * @param predicate  the predicate to decorate, not null
      * @return the predicate
      * @throws IllegalArgumentException if the predicate is null
      */
     public static <T> Predicate<T> nullIsFalsePredicate(final Predicate<? super T> predicate) {
         if (predicate == null) {
-            throw new IllegalArgumentException("Predicate must not be null");
+            throw new NullPointerException("Predicate must not be null");
         }
         return new NullIsFalsePredicate<T>(predicate);
     }
@@ -40,11 +40,11 @@ public final class NullIsFalsePredicate<
      * @param predicate  the predicate to decorate, not null
      * @return the predicate
-     * @throws IllegalArgumentException if the predicate is null
+     * @throws NullPointerException if the predicate is null
      */
     public static <T> Predicate<T> nullIsFalsePredicate(final Predicate<? super T> predicate) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsTruePredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsTruePredicate.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsTruePredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/NullIsTruePredicate.java Mon Jun 22 13:00:27 2015
@@ -40,11 +40,11 @@ public final class NullIsTruePredicate<T
      * @param <T> the type that the predicate queries
      * @param predicate  the predicate to decorate, not null
      * @return the predicate
      * @throws IllegalArgumentException if the predicate is null
      */
     public static <T> Predicate<T> nullIsTruePredicate(final Predicate<? super T> predicate) {
         if (predicate == null) {
-            throw new IllegalArgumentException("Predicate must not be null");
+            throw new NullPointerException("Predicate must not be null");
         }
         return new NullIsTruePredicate<T>(predicate);
     }
@@ -40,11 +40,11 @@ public final class NullIsTruePredicate<T
      * @param predicate  the predicate to decorate, not null
      * @return the predicate
-     * @throws IllegalArgumentException if the predicate is null
+     * @throws NullPointerException if the predicate is null
      */
     public static <T> Predicate<T> nullIsTruePredicate(final Predicate<? super T> predicate) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OnePredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OnePredicate.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OrPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/OrPredicate.java Mon Jun 22 13:00:27 2015
@@ -43,12 +43,12 @@ public final class OrPredicate<T> implem
      * @param predicate1  the first predicate to check, not null
      * @param predicate2  the second predicate to check, not null
      * @return the <code>and</code> predicate
      * @throws IllegalArgumentException if either predicate is null
      */
     public static <T> Predicate<T> orPredicate(final Predicate<? super T> predicate1,
                                                final Predicate<? super T> predicate2) {
         if (predicate1 == null || predicate2 == null) {
-            throw new IllegalArgumentException("Predicate must not be null");
+            throw new NullPointerException("Predicate must not be null");
         }
         return new OrPredicate<T>(predicate1, predicate2);
     }
@@ -43,12 +43,12 @@ public final class OrPredicate<T> implem
      * @param predicate2  the second predicate to check, not null
      * @return the <code>and</code> predicate
-     * @throws IllegalArgumentException if either predicate is null
+     * @throws NullPointerException if either predicate is null
      */
     public static <T> Predicate<T> orPredicate(final Predicate<? super T> predicate1,

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchClosure.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchClosure.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchClosure.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchClosure.java Mon Jun 22 13:00:27 2015
@@ -49,8 +49,9 @@ public class SwitchClosure<E> implements
      * @param closures  matching array of closures, cloned, no nulls
      * @param defaultClosure  the closure to use if no match, null means nop
      * @return the <code>chained</code> closure
      * @throws IllegalArgumentException if array is null
      * @throws IllegalArgumentException if any element in the array is null
      */
     @SuppressWarnings("unchecked")
     public static <E> Closure<E> switchClosure(final Predicate<? super E>[] predicates,
@@ -81,14 +82,14 @@ public class SwitchClosure<E> implements
      * @param <E> the type that the closure acts on
      * @param predicatesAndClosures  a map of predicates to closures
      * @return the <code>switch</code> closure
      * @throws IllegalArgumentException if the map is null
      * @throws IllegalArgumentException if any closure in the map is null
      * @throws ClassCastException  if the map elements are of the wrong type
      */
     @SuppressWarnings("unchecked")
     public static <E> Closure<E> switchClosure(final Map<Predicate<E>, Closure<E>> predicatesAndClosures) {
         if (predicatesAndClosures == null) {
-            throw new IllegalArgumentException("The predicate and closure map must not be null");
+            throw new NullPointerException("The predicate and closure map must not be null");
         }
         // convert to array like this to guarantee iterator() ordering
         final Closure<? super E> defaultClosure = predicatesAndClosures.remove(null);
@@ -49,8 +49,9 @@ public class SwitchClosure<E> implements
      * @param defaultClosure  the closure to use if no match, null means nop
      * @return the <code>chained</code> closure
-     * @throws IllegalArgumentException if array is null
-     * @throws IllegalArgumentException if any element in the array is null
+     * @throws NullPointerException if array is null
+     * @throws NullPointerException if any element in the array is null
+     * @throws IllegalArgumentException if the array lengths of predicates and closures do not match
      */
     @SuppressWarnings("unchecked")
@@ -81,14 +82,14 @@ public class SwitchClosure<E> implements
      * @param predicatesAndClosures  a map of predicates to closures
      * @return the <code>switch</code> closure
-     * @throws IllegalArgumentException if the map is null
-     * @throws IllegalArgumentException if any closure in the map is null
+     * @throws NullPointerException if the map is null
+     * @throws NullPointerException if any closure in the map is null
      * @throws ClassCastException  if the map elements are of the wrong type
      */

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchTransformer.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchTransformer.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/SwitchTransformer.java Mon Jun 22 13:00:27 2015
@@ -50,8 +50,8 @@ public class SwitchTransformer<I, O> imp
      * @param transformers  matching array of transformers, cloned, no nulls
      * @param defaultTransformer  the transformer to use if no match, null means return null
      * @return the <code>chained</code> transformer
      * @throws IllegalArgumentException if array is null
      * @throws IllegalArgumentException if any element in the array is null
      */
     @SuppressWarnings("unchecked")
     public static <I, O> Transformer<I, O> switchTransformer(final Predicate<? super I>[] predicates,
@@ -84,8 +84,8 @@ public class SwitchTransformer<I, O> imp
      * @param <O>  the output type
      * @param map  a map of predicates to transformers
      * @return the <code>switch</code> transformer
      * @throws IllegalArgumentException if the map is null
      * @throws IllegalArgumentException if any transformer in the map is null
      * @throws ClassCastException  if the map elements are of the wrong type
      */
     @SuppressWarnings("unchecked")
@@ -93,7 +93,7 @@ public class SwitchTransformer<I, O> imp
             final Map<? extends Predicate<? super I>, ? extends Transformer<? super I, ? extends O>> map) {
 
         if (map == null) {
-            throw new IllegalArgumentException("The predicate and transformer map must not be null");
+            throw new NullPointerException("The predicate and transformer map must not be null");
         }
         if (map.size() == 0) {
             return ConstantTransformer.<I, O>nullTransformer();
@@ -50,8 +50,8 @@ public class SwitchTransformer<I, O> imp
      * @param defaultTransformer  the transformer to use if no match, null means return null
      * @return the <code>chained</code> transformer
-     * @throws IllegalArgumentException if array is null
-     * @throws IllegalArgumentException if any element in the array is null
+     * @throws NullPointerException if array is null
+     * @throws NullPointerException if any element in the array is null
      */
     @SuppressWarnings("unchecked")
@@ -84,8 +84,8 @@ public class SwitchTransformer<I, O> imp
      * @param map  a map of predicates to transformers
      * @return the <code>switch</code> transformer
-     * @throws IllegalArgumentException if the map is null
-     * @throws IllegalArgumentException if any transformer in the map is null
+     * @throws NullPointerException if the map is null
+     * @throws NullPointerException if any transformer in the map is null
      * @throws ClassCastException  if the map elements are of the wrong type
      */

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformedPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformedPredicate.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformedPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformedPredicate.java Mon Jun 22 13:00:27 2015
@@ -46,15 +46,15 @@ public final class TransformedPredicate<
      * @param transformer  the transformer to call
      * @param predicate  the predicate to call with the result of the transform
      * @return the predicate
      * @throws IllegalArgumentException if the transformer or the predicate is null
      */
     public static <T> Predicate<T> transformedPredicate(final Transformer<? super T, ? extends T> transformer,
                                                         final Predicate<? super T> predicate) {
         if (transformer == null) {
-            throw new IllegalArgumentException("The transformer to call must not be null");
+            throw new NullPointerException("The transformer to call must not be null");
         }
         if (predicate == null) {
-            throw new IllegalArgumentException("The predicate to call must not be null");
+            throw new NullPointerException("The predicate to call must not be null");
         }
         return new TransformedPredicate<T>(transformer, predicate);
     }
@@ -46,15 +46,15 @@ public final class TransformedPredicate<
      * @param predicate  the predicate to call with the result of the transform
      * @return the predicate
-     * @throws IllegalArgumentException if the transformer or the predicate is null
+     * @throws NullPointerException if the transformer or the predicate is null
      */
     public static <T> Predicate<T> transformedPredicate(final Transformer<? super T, ? extends T> transformer,

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformerPredicate.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformerPredicate.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformerPredicate.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/TransformerPredicate.java Mon Jun 22 13:00:27 2015
@@ -42,11 +42,11 @@ public final class TransformerPredicate<
      * @param <T> the type that the predicate queries
      * @param transformer  the transformer to decorate
      * @return the predicate
      * @throws IllegalArgumentException if the transformer is null
      */
     public static <T> Predicate<T> transformerPredicate(final Transformer<? super T, Boolean> transformer) {
         if (transformer == null) {
-            throw new IllegalArgumentException("The transformer to call must not be null");
+            throw new NullPointerException("The transformer to call must not be null");
         }
         return new TransformerPredicate<T>(transformer);
     }
@@ -42,11 +42,11 @@ public final class TransformerPredicate<
      * @param transformer  the transformer to decorate
      * @return the predicate
-     * @throws IllegalArgumentException if the transformer is null
+     * @throws NullPointerException if the transformer is null
      */
     public static <T> Predicate<T> transformerPredicate(final Transformer<? super T, Boolean> transformer) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/WhileClosure.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/WhileClosure.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/WhileClosure.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/functors/WhileClosure.java Mon Jun 22 13:00:27 2015
@@ -48,15 +48,15 @@ public class WhileClosure<E> implements
      * @param closure  the closure the execute, not null
      * @param doLoop  true to act as a do-while loop, always executing the closure once
      * @return the <code>while</code> closure
      * @throws IllegalArgumentException if the predicate or closure is null
      */
     public static <E> Closure<E> whileClosure(final Predicate<? super E> predicate,
                                               final Closure<? super E> closure, final boolean doLoop) {
         if (predicate == null) {
-            throw new IllegalArgumentException("Predicate must not be null");
+            throw new NullPointerException("Predicate must not be null");
         }
         if (closure == null) {
-            throw new IllegalArgumentException("Closure must not be null");
+            throw new NullPointerException("Closure must not be null");
         }
         return new WhileClosure<E>(predicate, closure, doLoop);
     }
@@ -48,15 +48,15 @@ public class WhileClosure<E> implements
      * @param doLoop  true to act as a do-while loop, always executing the closure once
      * @return the <code>while</code> closure
-     * @throws IllegalArgumentException if the predicate or closure is null
+     * @throws NullPointerException if the predicate or closure is null
      */
     public static <E> Closure<E> whileClosure(final Predicate<? super E> predicate,

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractIteratorDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/AbstractIteratorDecorator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/BoundedIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/BoundedIterator.java Mon Jun 22 13:00:27 2015
@@ -57,11 +57,12 @@ public class BoundedIterator<E> implemen
      * @param iterator  the iterator to be decorated
      * @param offset  the index of the first element of the decorated iterator to return
      * @param max  the maximum number of elements of the decorated iterator to return
      * @throws IllegalArgumentException if iterator is null, or either offset or max is negative
      */
     public BoundedIterator(final Iterator<? extends E> iterator, final long offset, final long max) {
         if (iterator == null) {
-            throw new IllegalArgumentException("Iterator must not be null");
+            throw new NullPointerException("Iterator must not be null");
         }
         if (offset < 0) {
             throw new IllegalArgumentException("Offset parameter must not be negative.");
@@ -57,11 +57,12 @@ public class BoundedIterator<E> implemen
      * @param offset  the index of the first element of the decorated iterator to return
      * @param max  the maximum number of elements of the decorated iterator to return
-     * @throws IllegalArgumentException if iterator is null, or either offset or max is negative
+     * @throws NullPointerException if iterator is null
+     * @throws IllegalArgumentException if either offset or max is negative
      */
     public BoundedIterator(final Iterator<? extends E> iterator, final long offset, final long max) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/NodeListIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/NodeListIterator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/NodeListIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/NodeListIterator.java Mon Jun 22 13:00:27 2015
@@ -17,6 +17,7 @@ package org.apache.commons.collections4.
 
 import java.util.Iterator;
 import java.util.NoSuchElementException;
+
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 
@@ -42,11 +43,11 @@ public class NodeListIterator implements
      * the specified node's childNodes.
      *
      * @param node Node, who's child nodes are wrapped by this class. Must not be null
      * @throws IllegalArgumentException if node is null
      */
     public NodeListIterator(final Node node) {
         if (node == null) {
-            throw new IllegalArgumentException("node must not be null!");
+            throw new NullPointerException("Node must not be null.");
         }
         this.nodeList = node.getChildNodes();
     }
@@ -56,11 +57,11 @@ public class NodeListIterator implements
      * <code>org.w3c.NodeList</code>
      *
      * @param nodeList node list, which is wrapped by this class. Must not be null
      * @throws IllegalArgumentException if nodeList is null
      */
     public NodeListIterator(final NodeList nodeList) {
         if (nodeList == null) {
-            throw new IllegalArgumentException("nodeList must not be null!");
+            throw new NullPointerException("NodeList must not be null.");
         }
         this.nodeList = nodeList;
     }
@@ -42,11 +43,11 @@ public class NodeListIterator implements
      *
      * @param node Node, who's child nodes are wrapped by this class. Must not be null
-     * @throws IllegalArgumentException if node is null
+     * @throws NullPointerException if node is null
      */
     public NodeListIterator(final Node node) {
@@ -56,11 +57,11 @@ public class NodeListIterator implements
      *
      * @param nodeList node list, which is wrapped by this class. Must not be null
-     * @throws IllegalArgumentException if nodeList is null
+     * @throws NullPointerException if nodeList is null
      */
     public NodeListIterator(final NodeList nodeList) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/PeekingIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/PeekingIterator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/PeekingIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/PeekingIterator.java Mon Jun 22 13:00:27 2015
@@ -53,11 +53,11 @@ public class PeekingIterator<E> implemen
      * @param <E>  the element type
      * @param iterator  the iterator to decorate
      * @return a new peeking iterator
      * @throws IllegalArgumentException if the iterator is null
      */
     public static <E> PeekingIterator<E> peekingIterator(final Iterator<? extends E> iterator) {
         if (iterator == null) {
-            throw new IllegalArgumentException("Iterator must not be null");
+            throw new NullPointerException("Iterator must not be null");
         }
         if (iterator instanceof PeekingIterator<?>) {
             @SuppressWarnings("unchecked") // safe cast
@@ -53,11 +53,11 @@ public class PeekingIterator<E> implemen
      * @param iterator  the iterator to decorate
      * @return a new peeking iterator
-     * @throws IllegalArgumentException if the iterator is null
+     * @throws NullPointerException if the iterator is null
      */
     public static <E> PeekingIterator<E> peekingIterator(final Iterator<? extends E> iterator) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/PushbackIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/PushbackIterator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/PushbackIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/PushbackIterator.java Mon Jun 22 13:00:27 2015
@@ -50,11 +50,11 @@ public class PushbackIterator<E> impleme
      * @param <E>  the element type
      * @param iterator  the iterator to decorate
      * @return a new peeking iterator
      * @throws IllegalArgumentException if the iterator is null
      */
     public static <E> PushbackIterator<E> pushbackIterator(final Iterator<? extends E> iterator) {
         if (iterator == null) {
-            throw new IllegalArgumentException("Iterator must not be null");
+            throw new NullPointerException("Iterator must not be null");
         }
         if (iterator instanceof PushbackIterator<?>) {
             @SuppressWarnings("unchecked") // safe cast
@@ -50,11 +50,11 @@ public class PushbackIterator<E> impleme
      * @param iterator  the iterator to decorate
      * @return a new peeking iterator
-     * @throws IllegalArgumentException if the iterator is null
+     * @throws NullPointerException if the iterator is null
      */
     public static <E> PushbackIterator<E> pushbackIterator(final Iterator<? extends E> iterator) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/ReverseListIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/ReverseListIterator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableIterator.java Mon Jun 22 13:00:27 2015
@@ -42,11 +42,11 @@ public final class UnmodifiableIterator<
      * @param <E>  the element type
      * @param iterator  the iterator to decorate
      * @return a new unmodifiable iterator
      * @throws IllegalArgumentException if the iterator is null
      */
     public static <E> Iterator<E> unmodifiableIterator(final Iterator<? extends E> iterator) {
         if (iterator == null) {
-            throw new IllegalArgumentException("Iterator must not be null");
+            throw new NullPointerException("Iterator must not be null");
         }
         if (iterator instanceof Unmodifiable) {
             @SuppressWarnings("unchecked") // safe to upcast
@@ -42,11 +42,11 @@ public final class UnmodifiableIterator<
      * @param iterator  the iterator to decorate
      * @return a new unmodifiable iterator
-     * @throws IllegalArgumentException if the iterator is null
+     * @throws NullPointerException if the iterator is null
      */
     public static <E> Iterator<E> unmodifiableIterator(final Iterator<? extends E> iterator) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableListIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableListIterator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableListIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableListIterator.java Mon Jun 22 13:00:27 2015
@@ -40,11 +40,11 @@ public final class UnmodifiableListItera
      * @param <E>  the element type
      * @param iterator  the iterator to decorate
      * @return a new unmodifiable list iterator
      * @throws IllegalArgumentException if the iterator is null
      */
     public static <E> ListIterator<E> umodifiableListIterator(final ListIterator<? extends E> iterator) {
         if (iterator == null) {
-            throw new IllegalArgumentException("ListIterator must not be null");
+            throw new NullPointerException("ListIterator must not be null");
         }
         if (iterator instanceof Unmodifiable) {
             @SuppressWarnings("unchecked") // safe to upcast
@@ -40,11 +40,11 @@ public final class UnmodifiableListItera
      * @param iterator  the iterator to decorate
      * @return a new unmodifiable list iterator
-     * @throws IllegalArgumentException if the iterator is null
+     * @throws NullPointerException if the iterator is null
      */
     public static <E> ListIterator<E> umodifiableListIterator(final ListIterator<? extends E> iterator) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableMapIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableMapIterator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableMapIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableMapIterator.java Mon Jun 22 13:00:27 2015
@@ -40,12 +40,12 @@ public final class UnmodifiableMapIterat
      * @param <V>  the value type
      * @param iterator  the iterator to decorate
      * @return a new unmodifiable map iterator
      * @throws IllegalArgumentException if the iterator is null
      */
     public static <K, V> MapIterator<K, V> unmodifiableMapIterator(
             final MapIterator<? extends K, ? extends V> iterator) {
         if (iterator == null) {
-            throw new IllegalArgumentException("MapIterator must not be null");
+            throw new NullPointerException("MapIterator must not be null");
         }
         if (iterator instanceof Unmodifiable) {
             @SuppressWarnings("unchecked") // safe to upcast
@@ -40,12 +40,12 @@ public final class UnmodifiableMapIterat
      * @param iterator  the iterator to decorate
      * @return a new unmodifiable map iterator
-     * @throws IllegalArgumentException if the iterator is null
+     * @throws NullPointerException if the iterator is null
      */
     public static <K, V> MapIterator<K, V> unmodifiableMapIterator(

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableOrderedMapIterator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableOrderedMapIterator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableOrderedMapIterator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/iterators/UnmodifiableOrderedMapIterator.java Mon Jun 22 13:00:27 2015
@@ -41,13 +41,13 @@ public final class UnmodifiableOrderedMa
      * @param <V>  the value type
      * @param iterator  the iterator to decorate
      * @return a new unmodifiable ordered map iterator
      * @throws IllegalArgumentException if the iterator is null
      */
     public static <K, V> OrderedMapIterator<K, V> unmodifiableOrderedMapIterator(
             final OrderedMapIterator<K, ? extends V> iterator) {
 
         if (iterator == null) {
-            throw new IllegalArgumentException("OrderedMapIterator must not be null");
+            throw new NullPointerException("OrderedMapIterator must not be null");
         }
         if (iterator instanceof Unmodifiable) {
             @SuppressWarnings("unchecked") // safe to upcast
@@ -41,13 +41,13 @@ public final class UnmodifiableOrderedMa
      * @param iterator  the iterator to decorate
      * @return a new unmodifiable ordered map iterator
-     * @throws IllegalArgumentException if the iterator is null
+     * @throws NullPointerException if the iterator is null
      */
     public static <K, V> OrderedMapIterator<K, V> unmodifiableOrderedMapIterator(

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/keyvalue/AbstractMapEntryDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/keyvalue/AbstractMapEntryDecorator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/keyvalue/AbstractMapEntryDecorator.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/keyvalue/AbstractMapEntryDecorator.java Mon Jun 22 13:00:27 2015
@@ -36,11 +36,11 @@ public abstract class AbstractMapEntryDe
      * Constructor that wraps (not copies).
      *
      * @param entry  the <code>Map.Entry</code> to decorate, must not be null
      * @throws IllegalArgumentException if the collection is null
      */
     public AbstractMapEntryDecorator(final Map.Entry<K, V> entry) {
         if (entry == null) {
-            throw new IllegalArgumentException("Map Entry must not be null");
+            throw new NullPointerException("Map Entry must not be null.");
         }
         this.entry = entry;
     }
@@ -36,11 +36,11 @@ public abstract class AbstractMapEntryDe
      *
      * @param entry  the <code>Map.Entry</code> to decorate, must not be null
-     * @throws IllegalArgumentException if the collection is null
+     * @throws NullPointerException if the collection is null
      */
     public AbstractMapEntryDecorator(final Map.Entry<K, V> entry) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/AbstractListDecorator.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/AbstractListDecorator.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/SetUniqueList.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/SetUniqueList.java Mon Jun 22 13:00:27 2015
@@ -65,12 +65,12 @@ public class SetUniqueList<E> extends Ab
      * @param <E>  the element type
      * @param list  the list to decorate, must not be null
      * @return a new {@link SetUniqueList}
      * @throws IllegalArgumentException if list is null
      * @since 4.0
      */
     public static <E> SetUniqueList<E> setUniqueList(final List<E> list) {
         if (list == null) {
-            throw new IllegalArgumentException("List must not be null");
+            throw new NullPointerException("List must not be null");
         }
         if (list.isEmpty()) {
             return new SetUniqueList<E>(list, new HashSet<E>());
@@ -90,12 +90,12 @@ public class SetUniqueList<E> extends Ab
      *
      * @param set  the set to decorate, must not be null
      * @param list  the list to decorate, must not be null
      * @throws IllegalArgumentException if set or list is null
      */
     protected SetUniqueList(final List<E> list, final Set<E> set) {
         super(list);
         if (set == null) {
-            throw new IllegalArgumentException("Set must not be null");
+            throw new NullPointerException("Set must not be null");
         }
         this.set = set;
     }
@@ -65,12 +65,12 @@ public class SetUniqueList<E> extends Ab
      * @param list  the list to decorate, must not be null
      * @return a new {@link SetUniqueList}
-     * @throws IllegalArgumentException if list is null
+     * @throws NullPointerException if list is null
      * @since 4.0
      */
@@ -90,12 +90,12 @@ public class SetUniqueList<E> extends Ab
      * @param set  the set to decorate, must not be null
      * @param list  the list to decorate, must not be null
-     * @throws IllegalArgumentException if set or list is null
+     * @throws NullPointerException if set or list is null
      */
     protected SetUniqueList(final List<E> list, final Set<E> set) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/TransformedList.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/list/TransformedList.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/DefaultedMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/DefaultedMap.java Mon Jun 22 13:00:27 2015
@@ -80,7 +80,7 @@ public class DefaultedMap<K, V> extends
      * @param map  the map to decorate, must not be null
      * @param defaultValue  the default value to return when the key is not found
      * @return a new defaulting map
      * @throws IllegalArgumentException if map is null
      * @since 4.0
      */
     public static <K, V> DefaultedMap<K, V> defaultedMap(final Map<K, V> map, final V defaultValue) {
@@ -98,7 +98,7 @@ public class DefaultedMap<K, V> extends
      * @param map  the map to decorate, must not be null
      * @param factory  the factory to use to create entries, must not be null
      * @return a new defaulting map
      * @throws IllegalArgumentException if map or factory is null
      * @since 4.0
      */
     public static <K, V> DefaultedMap<K, V> defaultedMap(final Map<K, V> map, final Factory<? extends V> factory) {
@@ -120,7 +120,7 @@ public class DefaultedMap<K, V> extends
      * @param map  the map to decorate, must not be null
      * @param transformer  the transformer to use as a factory to create entries, must not be null
      * @return a new defaulting map
      * @throws IllegalArgumentException if map or factory is null
      * @since 4.0
      */
     public static <K, V> Map<K, V> defaultedMap(final Map<K, V> map,
@@ -159,12 +159,12 @@ public class DefaultedMap<K, V> extends
      *
      * @param map  the map to decorate, must not be null
      * @param defaultValueTransformer  the value transformer to use
      * @throws IllegalArgumentException if map or transformer is null
      */
     protected DefaultedMap(final Map<K, V> map, final Transformer<? super K, ? extends V> defaultValueTransformer) {
         super(map);
         if (defaultValueTransformer == null) {
-            throw new IllegalArgumentException("transformer must not be null");
+            throw new NullPointerException("Transformer must not be null.");
         }
         this.value = defaultValueTransformer;
     }
@@ -80,7 +80,7 @@ public class DefaultedMap<K, V> extends
      * @param defaultValue  the default value to return when the key is not found
      * @return a new defaulting map
-     * @throws IllegalArgumentException if map is null
+     * @throws NullPointerException if map is null
      * @since 4.0
      */
@@ -98,7 +98,7 @@ public class DefaultedMap<K, V> extends
      * @param factory  the factory to use to create entries, must not be null
      * @return a new defaulting map
-     * @throws IllegalArgumentException if map or factory is null
+     * @throws NullPointerException if map or factory is null
      * @since 4.0
      */
@@ -120,7 +120,7 @@ public class DefaultedMap<K, V> extends
      * @param transformer  the transformer to use as a factory to create entries, must not be null
      * @return a new defaulting map
-     * @throws IllegalArgumentException if map or factory is null
+     * @throws NullPointerException if map or factory is null
      * @since 4.0
      */
@@ -159,12 +159,12 @@ public class DefaultedMap<K, V> extends
      * @param map  the map to decorate, must not be null
      * @param defaultValueTransformer  the value transformer to use
-     * @throws IllegalArgumentException if map or transformer is null
+     * @throws NullPointerException if map or transformer is null
      */
     protected DefaultedMap(final Map<K, V> map, final Transformer<? super K, ? extends V> defaultValueTransformer) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/FixedSizeMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/FixedSizeMap.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/LazyMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/LazyMap.java Mon Jun 22 13:00:27 2015
@@ -75,7 +75,7 @@ public class LazyMap<K, V> extends Abstr
      * @param map  the map to decorate, must not be null
      * @param factory  the factory to use, must not be null
      * @return a new lazy map
      * @throws IllegalArgumentException if map or factory is null
      * @since 4.0
      */
     public static <K, V> LazyMap<K, V> lazyMap(final Map<K, V> map, final Factory< ? extends V> factory) {
@@ -90,7 +90,7 @@ public class LazyMap<K, V> extends Abstr
      * @param map  the map to decorate, must not be null
      * @param factory  the factory to use, must not be null
      * @return a new lazy map
      * @throws IllegalArgumentException if map or factory is null
      * @since 4.0
      */
     public static <V, K> LazyMap<K, V> lazyMap(final Map<K, V> map, final Transformer<? super K, ? extends V> factory) {
@@ -103,12 +103,12 @@ public class LazyMap<K, V> extends Abstr
      *
      * @param map  the map to decorate, must not be null
      * @param factory  the factory to use, must not be null
      * @throws IllegalArgumentException if map or factory is null
      */
     protected LazyMap(final Map<K,V> map, final Factory<? extends V> factory) {
         super(map);
         if (factory == null) {
-            throw new IllegalArgumentException("Factory must not be null");
+            throw new NullPointerException("Factory must not be null");
         }
         this.factory = FactoryTransformer.factoryTransformer(factory);
     }
@@ -118,12 +118,12 @@ public class LazyMap<K, V> extends Abstr
      *
      * @param map  the map to decorate, must not be null
      * @param factory  the factory to use, must not be null
      * @throws IllegalArgumentException if map or factory is null
      */
     protected LazyMap(final Map<K,V> map, final Transformer<? super K, ? extends V> factory) {
         super(map);
         if (factory == null) {
-            throw new IllegalArgumentException("Factory must not be null");
+            throw new NullPointerException("Factory must not be null");
         }
         this.factory = factory;
     }
@@ -75,7 +75,7 @@ public class LazyMap<K, V> extends Abstr
      * @param factory  the factory to use, must not be null
      * @return a new lazy map
-     * @throws IllegalArgumentException if map or factory is null
+     * @throws NullPointerException if map or factory is null
      * @since 4.0
      */
@@ -90,7 +90,7 @@ public class LazyMap<K, V> extends Abstr
      * @param factory  the factory to use, must not be null
      * @return a new lazy map
-     * @throws IllegalArgumentException if map or factory is null
+     * @throws NullPointerException if map or factory is null
      * @since 4.0
      */
@@ -103,12 +103,12 @@ public class LazyMap<K, V> extends Abstr
      * @param map  the map to decorate, must not be null
      * @param factory  the factory to use, must not be null
-     * @throws IllegalArgumentException if map or factory is null
+     * @throws NullPointerException if map or factory is null
      */
     protected LazyMap(final Map<K,V> map, final Factory<? extends V> factory) {
@@ -118,12 +118,12 @@ public class LazyMap<K, V> extends Abstr
      * @param map  the map to decorate, must not be null
      * @param factory  the factory to use, must not be null
-     * @throws IllegalArgumentException if map or factory is null
+     * @throws NullPointerException if map or factory is null
      */
     protected LazyMap(final Map<K,V> map, final Transformer<? super K, ? extends V> factory) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/LazySortedMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/LazySortedMap.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/MultiKeyMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/MultiKeyMap.java Mon Jun 22 13:00:27 2015
@@ -89,12 +89,13 @@ public class MultiKeyMap<K, V> extends A
      * @param <V>  the value type
      * @param map  the map to decorate, not null
      * @return a new multi key map
      * @throws IllegalArgumentException if the map is null or not empty
      * @since 4.0
      */
     public static <K, V> MultiKeyMap<K, V> multiKeyMap(final AbstractHashedMap<MultiKey<? extends K>, V> map) {
         if (map == null) {
-            throw new IllegalArgumentException("Map must not be null");
+            throw new NullPointerException("Map must not be null");
         }
         if (map.size() > 0) {
             throw new IllegalArgumentException("Map must be empty");
@@ -89,12 +89,13 @@ public class MultiKeyMap<K, V> extends A
      * @param map  the map to decorate, not null
      * @return a new multi key map
-     * @throws IllegalArgumentException if the map is null or not empty
+     * @throws NullPointerException if map is null
+     * @throws IllegalArgumentException if the map is not empty
      * @since 4.0
      */

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/PassiveExpiringMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/PassiveExpiringMap.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================
--- commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/PassiveExpiringMap.java (original)
+++ commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/PassiveExpiringMap.java Mon Jun 22 13:00:27 2015
@@ -117,7 +117,7 @@ public class PassiveExpiringMap<K, V>
          *        expire.
          * @param timeUnit the unit of time for the <code>timeToLive</code>
          *        parameter, must not be null.
          * @throws IllegalArgumentException if the time unit is null.
          */
         public ConstantTimeToLiveExpirationPolicy(final long timeToLive,
                                                   final TimeUnit timeUnit) {
@@ -181,20 +181,19 @@ public class PassiveExpiringMap<K, V>
     /**
      * First validate the input parameters. If the parameters are valid, convert
      * the given time measured in the given units to the same time measured in
-     * milliseconds. If the parameters are invalid, an
-     * {@link IllegalArgumentException} is thrown.
+     * milliseconds.
      *
      * @param timeToLive the constant amount of time an entry is available
      *        before it expires. A negative value results in entries that NEVER
      *        expire. A zero value results in entries that ALWAYS expire.
      * @param timeUnit the unit of time for the <code>timeToLive</code>
      *        parameter, must not be null.
      * @throws IllegalArgumentException if the time unit is null.
      */
     private static long validateAndConvertToMillis(final long timeToLive,
                                                    final TimeUnit timeUnit) {
         if (timeUnit == null) {
-            throw new IllegalArgumentException("Time unit must not be null");
+            throw new NullPointerException("Time unit must not be null");
         }
         return TimeUnit.MILLISECONDS.convert(timeToLive, timeUnit);
     }
@@ -219,6 +218,7 @@ public class PassiveExpiringMap<K, V>
      *
      * @param expiringPolicy the policy used to determine expiration times of
      *        entries as they are added.
+     * @throws NullPointerException if expiringPolicy is null
      */
     public PassiveExpiringMap(final ExpirationPolicy<K, V> expiringPolicy) {
         this(expiringPolicy, new HashMap<K, V>());
@@ -233,13 +233,13 @@ public class PassiveExpiringMap<K, V>
      * @param expiringPolicy the policy used to determine expiration times of
      *        entries as they are added.
      * @param map the map to decorate, must not be null.
-     * @throws IllegalArgumentException if the map is null.
+     * @throws NullPointerException if the map or expiringPolicy is null.
      */
     public PassiveExpiringMap(final ExpirationPolicy<K, V> expiringPolicy,
                               final Map<K, V> map) {
         super(map);
         if (expiringPolicy == null) {
-            throw new IllegalArgumentException("Policy must not be null.");
+            throw new NullPointerException("Policy must not be null.");
         }
         this.expiringPolicy = expiringPolicy;
     }
@@ -271,7 +271,7 @@ public class PassiveExpiringMap<K, V>
      *        entries that NEVER expire. A zero value results in entries that
      *        ALWAYS expire.
      * @param map the map to decorate, must not be null.
      * @throws IllegalArgumentException if the map is null.
      */
     public PassiveExpiringMap(final long timeToLiveMillis, final Map<K, V> map) {
         this(new ConstantTimeToLiveExpirationPolicy<K, V>(timeToLiveMillis),
@@ -288,7 +288,7 @@ public class PassiveExpiringMap<K, V>
      *        expire. A zero value results in entries that ALWAYS expire.
      * @param timeUnit the unit of time for the <code>timeToLive</code>
      *        parameter, must not be null.
      * @throws IllegalArgumentException if the time unit is null.
      */
     public PassiveExpiringMap(final long timeToLive, final TimeUnit timeUnit) {
         this(validateAndConvertToMillis(timeToLive, timeUnit));
@@ -308,8 +308,7 @@ public class PassiveExpiringMap<K, V>
      * @param timeUnit the unit of time for the <code>timeToLive</code>
      *        parameter, must not be null.
      * @param map the map to decorate, must not be null.
      * @throws IllegalArgumentException if the time unit is null.
      * @throws IllegalArgumentException if the map is null.
      */
     public PassiveExpiringMap(final long timeToLive, final TimeUnit timeUnit, final Map<K, V> map) {
         this(validateAndConvertToMillis(timeToLive, timeUnit), map);
@@ -321,7 +320,7 @@ public class PassiveExpiringMap<K, V>
      * being decorated, they also will NEVER expire.
      *
      * @param map the map to decorate, must not be null.
      * @throws IllegalArgumentException if the map is null.
      */
     public PassiveExpiringMap(final Map<K, V> map) {
         this(-1L, map);
@@ -117,7 +117,7 @@ public class PassiveExpiringMap<K, V>
          * @param timeUnit the unit of time for the <code>timeToLive</code>
          *        parameter, must not be null.
-         * @throws IllegalArgumentException if the time unit is null.
+         * @throws NullPointerException if the time unit is null.
          */
         public ConstantTimeToLiveExpirationPolicy(final long timeToLive,
@@ -181,20 +181,19 @@ public class PassiveExpiringMap<K, V>
      * @param timeUnit the unit of time for the <code>timeToLive</code>
      *        parameter, must not be null.
-     * @throws IllegalArgumentException if the time unit is null.
+     * @throws NullPointerException if the time unit is null.
      */
     private static long validateAndConvertToMillis(final long timeToLive,
@@ -271,7 +271,7 @@ public class PassiveExpiringMap<K, V>
      *        ALWAYS expire.
      * @param map the map to decorate, must not be null.
-     * @throws IllegalArgumentException if the map is null.
+     * @throws NullPointerException if the map is null.
      */
     public PassiveExpiringMap(final long timeToLiveMillis, final Map<K, V> map) {
@@ -288,7 +288,7 @@ public class PassiveExpiringMap<K, V>
      * @param timeUnit the unit of time for the <code>timeToLive</code>
      *        parameter, must not be null.
-     * @throws IllegalArgumentException if the time unit is null.
+     * @throws NullPointerException if the time unit is null.
      */
     public PassiveExpiringMap(final long timeToLive, final TimeUnit timeUnit) {
@@ -308,8 +308,7 @@ public class PassiveExpiringMap<K, V>
      *        parameter, must not be null.
      * @param map the map to decorate, must not be null.
-     * @throws IllegalArgumentException if the time unit is null.
-     * @throws IllegalArgumentException if the map is null.
+     * @throws NullPointerException if the map or time unit is null.
      */
     public PassiveExpiringMap(final long timeToLive, final TimeUnit timeUnit, final Map<K, V> map) {
@@ -321,7 +320,7 @@ public class PassiveExpiringMap<K, V>
      *
      * @param map the map to decorate, must not be null.
-     * @throws IllegalArgumentException if the map is null.
+     * @throws NullPointerException if the map is null.
      */
     public PassiveExpiringMap(final Map<K, V> map) {

Modified: commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/PredicatedMap.java
URL: http://svn.apache.org/viewvc/commons/proper/collections/trunk/src/main/java/org/apache/commons/collections4/map/PredicatedMap.java?rev=1686855&r1=1686854&r2=1686855&view=diff
==============================================================================